function varargout = serialtrace_v1_1_gui(varargin)
% SERIALTRACE_V1_1_GUI M-file for serialtrace_v1_1_gui.fig
%      SERIALTRACE_V1_1_GUI, by itself, creates a new SERIALTRACE_V1_1_GUI or raises the existing
%      singleton*.
%
%      H = SERIALTRACE_V1_1_GUI returns the handle to a new SERIALTRACE_V1_1_GUI or the handle to
%      the existing singleton*.
%
%      SERIALTRACE_V1_1_GUI('Property','Value',...) creates a new SERIALTRACE_V1_1_GUI using the
%      given property value pairs. Unrecognized properties are passed via
%      varargin to serialtrace_v1_1_gui_OpeningFcn.  This calling syntax produces a
%      warning when there is an existing singleton*.
%
%      SERIALTRACE_V1_1_GUI('CALLBACK') and SERIALTRACE_V1_1_GUI('CALLBACK',hObject,...) call the
%      local function named CALLBACK in SERIALTRACE_V1_1_GUI.M with the given input
%      arguments.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help serialtrace_v1_1_gui

% Last Modified by GUIDE v2.5 28-Apr-2004 10:40:40

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @serialtrace_v1_1_gui_OpeningFcn, ...
                   'gui_OutputFcn',  @serialtrace_v1_1_gui_OutputFcn, ...
                   'gui_LayoutFcn',  [], ...
                   'gui_Callback',   []);
if nargin & isstr(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before serialtrace_v1_1_gui is made visible.
function serialtrace_v1_1_gui_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   unrecognized PropertyName/PropertyValue pairs from the
%            command line (see VARARGIN)

% Choose default command line output for serialtrace_v1_1_gui
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes serialtrace_v1_1_gui wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = serialtrace_v1_1_gui_OutputFcn(hObject, eventdata, handles)
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles;


% --- Executes on button press in disconnect.
function disconnect_Callback(hObject, eventdata, handles)
% hObject    handle to disconnect (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of disconnect


% --- Executes during object creation, after setting all properties.
function realtimeymax_CreateFcn(hObject, eventdata, handles)
% hObject    handle to realtimeymax (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end


function realtimeymax_Callback(hObject, eventdata, handles)
% hObject    handle to realtimeymax (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of realtimeymax as text
%        str2double(get(hObject,'String')) returns contents of realtimeymax as a double


% --- Executes during object creation, after setting all properties.
function realtimeymin_CreateFcn(hObject, eventdata, handles)
% hObject    handle to realtimeymin (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end


function realtimeymin_Callback(hObject, eventdata, handles)
% hObject    handle to realtimeymin (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of realtimeymin as text
%        str2double(get(hObject,'String')) returns contents of realtimeymin as a double


% --- Executes during object creation, after setting all properties.
function zoomymax_CreateFcn(hObject, eventdata, handles)
% hObject    handle to zoomymax (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end


function zoomymax_Callback(hObject, eventdata, handles)
% hObject    handle to zoomymax (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of zoomymax as text
%        str2double(get(hObject,'String')) returns contents of zoomymax as a double


% --- Executes during object creation, after setting all properties.
function zoomymin_CreateFcn(hObject, eventdata, handles)
% hObject    handle to zoomymin (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end


function zoomymin_Callback(hObject, eventdata, handles)
% hObject    handle to zoomymin (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of zoomymin as text
%        str2double(get(hObject,'String')) returns contents of zoomymin as a double


% --- Executes during object creation, after setting all properties.
function zoomxmax_CreateFcn(hObject, eventdata, handles)
% hObject    handle to zoomxmax (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end


function zoomxmax_Callback(hObject, eventdata, handles)
% hObject    handle to zoomxmax (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of zoomxmax as text
%        str2double(get(hObject,'String')) returns contents of zoomxmax as a double


% --- Executes during object creation, after setting all properties.
function zoomxmin_CreateFcn(hObject, eventdata, handles)
% hObject    handle to zoomxmin (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end


function zoomxmin_Callback(hObject, eventdata, handles)
% hObject    handle to zoomxmin (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of zoomxmin as text
%        str2double(get(hObject,'String')) returns contents of zoomxmin as a double


% --- Executes during object creation, after setting all properties.
function realtimexmax_CreateFcn(hObject, eventdata, handles)
% hObject    handle to realtimexmax (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end


function realtimexmax_Callback(hObject, eventdata, handles)
% hObject    handle to realtimexmax (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of realtimexmax as text
%        str2double(get(hObject,'String')) returns contents of realtimexmax as a double


% --- Executes during object creation, after setting all properties.
function realtimexmin_CreateFcn(hObject, eventdata, handles)
% hObject    handle to realtimexmin (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end


function realtimexmin_Callback(hObject, eventdata, handles)
% hObject    handle to realtimexmin (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of realtimexmin as text
%        str2double(get(hObject,'String')) returns contents of realtimexmin as a double


% --- Executes on button press in autoscale.
function autoscale_Callback(hObject, eventdata, handles)
% hObject    handle to autoscale (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of autoscale


% --- Executes on button press in definezoom.
function definezoom_Callback(hObject, eventdata, handles)
% hObject    handle to definezoom (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of definezoom


